@@ -7,7 +7,7 @@ def simple_app(environ, start_response):
     start_response(status, response_headers)
     return ['Hello world!\n']
     
-def main(port):
-    httpd = HTTPApplication("127.0.0.1", port)
+def main(**kwargs):
+    httpd = HTTPApplication(kwargs['domain'], kwargs['port'])
     httpd.add_wsgi_rule("/", simple_app)
     httpd.start()
